---
title: Chemodiversity
subtitle: A short overview of this project
author: Stefan Dresselhaus
license: BSD
affiliation: Theoretic Biology Group<br>
             Bielefeld University
abstract: Attempt to find indications for chemodiversity in the plant secondary metabolism according to the screening hypothesis
date: \today

papersize: a4
fontsize: 10pt
documentclass: scrartcl

margin: 0.2
slideNumber: true
...


What is chemodiversity?
-----------------------

- It was observed, that many plants seem to produce many compounds with no
  obvious purpose
- Using resources to produce such compounds (instead of i.e. growing) should
  yield a fitness-disadvantage
- one expects evolution to eliminate such behavior

Question: Why is this behavior observed?
--------------------------------

- Are these compounds necessary for some unresearched reason?
  - unknown environmental effects?
  - unknown intermediate products for necessary defenses?
  - speculative diversity because they could be useful after genetic mutations?

Screening Hypothesis
--------------------

- First suggested by Jones & Firn ([1991](https://doi.org/10.1098/rstb.1991.0077))
- new (random) compounds are rarely biologically active
- plants have a higher chance finding an active compound if they diversify
- many (inactive) compounds are sustained for a while because they may be
  precursors to biologically active substances

. . .

There are indications for and against this hypothesis by [various groups](https://nph.onlinelibrary.wiley.com/doi/full/10.1111/nph.12526#nph12526-bib-0093).


--------------------------------------------------------------------------------

Setting up a simulation
=======================

>If you wish to make apple pie from scratch, you must first create the universe  
>  - Carl Sagan

--------------------------------------------------------------------------------

Defining Chemistry
------------------

- First of all we define the chemistry of our environment, so we know all possible
interactions and can manipulate them at will.
- We differentiate between **`Substrate`{.haskell}** and
  **`Products`{.haskell}**:
  - **`Substrate`{.haskell
}** can just be used (i.e. real substrates if the whole metabolism
  should be simulated, **`PPM`{.haskell}**^[1]^  in our simplified case)
  - **`Products`{.haskell
}** are nodes in our chemistry environment.
- In Code:  
  ```haskell
  data Compound = Substrate Nutrient
                | Produced Component
                | GenericCompound Int
  ```
::: footer
^[1]^: plants primary metabolism
:::


Usage in the current Model
--------------------------

- The Model used for evaluation just has one `Substrate`{.haskell}:  
  `PPM`{.haskell} with a fixed Amount to account for effects of sucking
  primary-metabolism-products out of the primary metabolic cycle
- This is used to simulate i.e. worse growth, fertility and other things
  affecting the fitness of a plant.
- We are not using named Compounds, but restrict to generic `Compound
  1`{.haskell},
  `Compound 2`{.haskell} ...
- Not done, but worth exploring:
  - Take a "real-world" snapshot of Nutrients and Compounds and recreate them
  - See if the simulation follows the real world


Defining a Metabolism
---------------------

- We define **`Enzyme`{.haskell}s** as
  - having a recipe for a chemical reaction
  - are reversible
  - may have dependencies on catalysts to be present
  - may have higher dominance over other enzymes with the same reaction

- Input can be `Substrate`{.haskell} and/or `Products`{.haskell}
- Outputs can only be `Products`{.haskell}
- $\Rightarrow$ This makes them to Edges in a graph combining the chemical
  compounds

Usage in the current Model
--------------------------

- `Enzyme`{.haskell}s all
  - only map `1`{.haskell} input to `1`{.haskell} Output with a production rate of `1`{.haskell} per `Enzyme`{.haskell}  
    (i.e. `-1 Compound 2 -> +1 Compound 5`{.haskell})
  - are equally dominant
  - need no catalysts

Defining Predators
------------------

- **`Predator`{.haskell}s** consist of
  - a list of `Compound`{.haskell}s that can kill them
  - a fitness impact ($[0..1]$) as the probability of killing the plant
  - an expected number of attacks per generation
  - a probability ($[0..1]$) of appearing in a single generation
- `Predator`{.haskell} need not necessary be biologically motivated
  - i.e. rare, nearly devastating attacks (floods, droughts, ...) with realistic
    probabilities

Example Environment
-------------------

:::::::::::::: {.columns}

::: {.column width=37%}

- The complete environment now consists of
  - `Compound`{.haskell}s:  
    ![](img/compound_example.png){style="vertical-align:middle"}
  - `Enzyme`{.haskell}s:  
    ![](img/enzyme_example.png){style="vertical-align:middle"}
  - `Predator`{.haskell}s:  
    ![](img/predator_example.png){style="vertical-align:middle"}

:::

::: {.column width=63% .fragment}

![Our default test-environment](img/environment.tree.png){width=75%}

Additional rules:

- Every "subtree" from the marked `PPM`{.haskell} is treated as a separate
  species (fungi, animals, ...)  
  $\Rightarrow$ Every predator can only be affected by toxins in the same part of the tree
- Trees can be automatically generated in a decent manner to search for
  environmens where specific effects may arise
:::

::::::::::::::

::::: notes :::::

CTRL+Click for zoom!

- All starts at PPM (Plant Primary Metabolism)
- Red = Toxic
- Blue = Predators

::::

--------------------------------------------------------------------------------

Plants
------

A plant consists of
...


Metabolism simulation
---------------------

Compounds are created foo..


Fitness
-------

- Static costs of enzymes
- Cost of active enzymes


Attacker
--------

- Rate of attack ~> Paper, Formulas
- Defenses
  - single plant
  - automimicry

Haploid mating
--------------

- fixed population-size (100)
- $p(\textrm{reproduction}) = \frac{\textrm{plant-fitness}}{\textrm{total fitness in population}}$
- Gene
  - mutation
  - duplication
  - deletion
  - addition
  - activation-noise

--------------------------------------------------------------------------------

Simulations
-----------

Parameters tested

- x
- y
- z

--------------------------------------------------------------------------------

Results
=======

>It doesn't matter how beautiful your theory is, it doesn't matter how smart you are. If it doesn't agree with experiment, it's wrong.  
>  - Richard P. Feynman

--------------------------------------------------------------------------------

















